GLOBAL.require("map/level")
local GROUND = GLOBAL.GROUND
local WorldSim = GLOBAL.WorldSim

--This is my first worldgen mod

LEVELTYPE = {
	SURVIVAL = 1,
	CAVE = 2,
	ADVENTURE = 3,
	TEST = 4,
	UNKNOWN = 5,
	CUSTOM = 6,
	VOLCANO = 7,
	SHIPWRECKED = 8,
}

AddLevel(LEVELTYPE.SHIPWRECKED, {
		id="tiny",
		name="Tiny world",
		desc="A smaller shipwrkecked",
		overrides={
				{"start_setpeice", 	"ShipwreckedStart"}, --You start in a setpiece, this one is a grass patch with flowers. 
				{"start_node",		"BeachSand"},  --This is the room (biome) you start in 'BeachSand' comes from terrain_beach.lua
				{"start_task",		"HomeIsland"}, --The island (task) you start on. From the list of 'tasks' below
				{"location",		"shipwrecked"},
				{"roads", 			"never"}, 
				{"loop",			"never"},
				{"poi",				"never"},
				{"world_size",		"tiny"}, --World size: tiny, small, default, medium, large, or huge. Actual values are in map/forest_map.lua approx line 270
		},

		--Tasks (Island recipes) are sets of rooms (biomes) that define an island. These tasks will be inserted
		--into the world based on a lock/key system. Tasks can only be used once
		--Shipwrecked tasks are currently in map/tasks/island.lua

		--One of these tasks is picked as the start_task, based on weight
		--start_setpiece and start_node, from above, are the defaults
		start_tasks = {
			["HomeIslandVerySmall"] = {
				weight = .5,
				start_setpiece = "ShipwreckedStart",
				start_node = "BeachSandHome"
			},
			["HomeIslandSmall"] = {
				weight = 1,
				start_setpiece = "ShipwreckedStart",
				start_node = "BeachSandHome"
			},
			["HomeIslandSmallBoon"] = {
				weight = .2,
				start_setpiece = "ShipwreckedStart",
				start_node = "BeachSandHome"
			},
		},

		--These tasks are always part of the world.
		tasks = {
			"DesertIsland",
			"DoydoyIslandGirl",
			"DoydoyIslandBoy",
			"IslandCasino",
			"PirateBounty", --NEW
			"ShellingOut", --NEW
			"JungleMarsh",
			"IslandMangroveOxBoon",
			"SharkHome",
			"IslandOasis",
			"IslandMeadowCarroty",
			},



-- =====================================================================
--                          "RING" GENERATION METHOD
-- =====================================================================

		--These are optional tasks. World gen will randomly pick 'numoptionaltasks' from the list
		--and add them to the world
		--numoptionaltasks = 9,
		--optionaltasks = {
		--},

		--These are optional tasks. For each group WorldGen will randomly pick between 'min' and 'max'
		--from the 'task_choices' and add them to the world.
		selectedtasks = {
			{ -- RING NONE
				min = 2, --2
				max = 3, --3
				task_choices = {
					"BeachBothJungles",
					"IslandParadise",
					"Cranium",
					"GreentipA",
				}
			},

		},


-- =====================================================================
--                         END OF "RING" GENERATION METHOD
-- =====================================================================

		--The random range of background rooms (biomes) that get added to each room in a task.
		background_node_range = {0, 2},

		water_content = {
			["WaterAll"] = {checkFn = function(ground) return WorldSim:IsWater(ground) and not WorldSim:IsShore(ground) end},
			["WaterShallow"] = {checkFn = function(ground) return ground == GROUND.OCEAN_SHALLOW end},
			["WaterMedium"] = {checkFn = function(ground) return ground == GROUND.OCEAN_MEDIUM end},
			["WaterDeep"] = {checkFn = function(ground) return ground == GROUND.OCEAN_DEEP end},
			["WaterCoral"] = {checkFn = function(ground) return ground == GROUND.OCEAN_CORAL end},
			--["WaterMangrove"] = {checkFn = function(ground) return ground == GROUND.MANGROVE end},
			["WaterShipGraveyard"] = {checkFn = function(ground) return ground == GROUND.OCEAN_SHIPGRAVEYARD end},
		},

		set_pieces = {
			["ResurrectionStoneSw"] = {
				count=2,
				tasks={ 
					"IslandParadise",
					"VerdantMost",
					"AllBeige",
					"NoGreen B",
					"Florida Timeshare",
					"PiggyParadise",
					"JungleDRockyland",
					"JungleDRockyMarsh",
					"JungleDSavRock",
					"IslandJungleRockyDrop", 
				}
			},
			--["ShipwreckedExit"] = { count=1, tasks={ "IslandParadise", "DesertIsland" } },
			--["RockSkull"] = { count=1, tasks={ "Cranium" } },

			["SWPortal"] = { count=1, tasks={
					"VerdantMost",
					"GreentipA",
					"HalfGreen",
					"LotsaGrass",
					"AllBeige",
					"Verdant",
					"Vert",
					"Florida Timeshare",
					"PiggyParadise",
					"Spiderland",
					"JungleDRockyland",
					"JungleDRockyMarsh",
					"JungleDSavRock",
					"FullofBees",
					"IslandJungleRockyDrop",
					"NoGreen B",
					"IslandMeadowCarroty",
				} 
			},
		},

		numrandom_set_pieces = 0,
		random_set_pieces = {
		},

		water_prefill_setpieces = {
			["TeleportatoSwBaseLayout"] = {count = 1}
		},

		-- water_setpieces =
		-- {
		-- 	"WilburUnlock",
		-- },

		treasures = {
			["TestTreasure"] = { count = 1, treasuretasks = {"DesertIsland"}, maptasks = {"IslandParadise"}, tasks = {"IslandParadise"} },
		},

		numoptional_treasures = 0,
		optional_treasures = {
		},

		numrandom_treasures = 16,
		random_treasures = {
			"SeaPackageQuest",
			"PirateBank",
			"PiratePeanuts",
			"RandomGem",
			"DubloonsGem",
			"minerhat",
			"SuperTelescope",
			"ChickenOfTheSea",
			--"WoodlegsKey1",
			--"WoodlegsKey2",
			--"WoodlegsKey3",
			"BootyInDaBooty",
			"OneTrueEarring",
			"PegLeg",
			"VolcanoStaff",
			"Gladiator",
			"FancyHandyMan",
			"LobsterMan",
			"Compass",
			"Scientist",
			"Alchemist",
			"Shaman",
			"FireBrand",
			"SailorsDelight",
			"WarShip",
			"Desperado",
			"JewelThief",
			"AntiqueWarrior",
			"Yaar",
			"GdayMate",
			"ToxicAvenger",
			"MadBomber",
			"FancyAdventurer",
			"ThunderBall",
			"TombRaider",
			"SteamPunk",
			"CapNCrunch",
			"AyeAyeCapn",
			"BreakWind",
			"Diviner",
			"GoesComesAround",
			"GoldGoldGold",
			"FirePoker",
		},

		ordered_story_setpieces = {
			"TeleportatoSwRingLayout",
			"TeleportatoSwBoxLayout",
			"TeleportatoSwCrankLayout",
			"TeleportatoSwPotatoLayout",
			--"TeleportatoSwBaseLayout",
		},

		required_prefabs = 
		{
			"volcano", 
			"packim_fishbone", 
			"sharkittenspawner",
			"octopusking",
			"teleportato_sw_ring", 
			"teleportato_sw_box", 
			"teleportato_sw_crank", 
			"teleportato_sw_potato", 
			"teleportato_sw_base",
			"wilbur_unlock_marker",
			"portal_shipwrecked"
		},

		required_prefab_count = 
		{
			["doydoy"] = 2
		},

		required_treasures = {}
	})